@@ -350,7 +350,7 @@ KDbLookupFieldSchema *KDbLookupFieldSchema::loadFromDom(const QDomElement& looku
             const QVariant val = KDb::loadPropertyValueFromDom(el.firstChild(), &ok);
             if (!ok || !::setBoundColumn(lookupFieldSchema, val)) {
                 delete lookupFieldSchema;
-                return 0;
+                return nullptr;
             }
         } else if (name == "visible-column") {
             /* <visible-column> #a column that has to be visible in the combo box
@@ -366,13 +366,13 @@ KDbLookupFieldSchema *KDbLookupFieldSchema::loadFromDom(const QDomElement& looku
                 const QVariant val = KDb::loadPropertyValueFromDom(childNode, &ok);
                 if (!ok) {
                     delete lookupFieldSchema;
-                    return 0;
+                    return nullptr;
                 }
                 list.append(val);
             }
             if (!::setVisibleColumns(lookupFieldSchema, list)) {
                 delete lookupFieldSchema;
-                return 0;
+                return nullptr;
             }
         } else if (name == "column-widths") {
             /* <column-widths> #column widths, -1 means 'default'
@@ -386,13 +386,13 @@ KDbLookupFieldSchema *KDbLookupFieldSchema::loadFromDom(const QDomElement& looku
                 QVariant val = KDb::loadPropertyValueFromDom(el, &ok);
                 if (!ok) {
                     delete lookupFieldSchema;
-                    return 0;
+                    return nullptr;
                 }
                 columnWidths.append(val);
             }
             if (!::setColumnWidths(lookupFieldSchema, columnWidths)) {
                 delete lookupFieldSchema;
-                return 0;
+                return nullptr;
             }
         } else if (name == "show-column-headers") {
             /* <show-column-headers>
@@ -402,7 +402,7 @@ KDbLookupFieldSchema *KDbLookupFieldSchema::loadFromDom(const QDomElement& looku
             const QVariant val = KDb::loadPropertyValueFromDom(el.firstChild(), &ok);
             if (!ok) {
                 delete lookupFieldSchema;
-                return 0;
+                return nullptr;
             }
             if (val.type() == QVariant::Bool)
                 lookupFieldSchema->setColumnHeadersVisible(val.toBool());
@@ -414,7 +414,7 @@ KDbLookupFieldSchema *KDbLookupFieldSchema::loadFromDom(const QDomElement& looku
             const QVariant val = KDb::loadPropertyValueFromDom(el.firstChild(), &ok);
             if (!ok) {
                 delete lookupFieldSchema;
-                return 0;
+                return nullptr;
             }
             if (val.type() == QVariant::Int)
                 lookupFieldSchema->setMaxVisibleRecords(val.toInt());
@@ -426,7 +426,7 @@ KDbLookupFieldSchema *KDbLookupFieldSchema::loadFromDom(const QDomElement& looku
             const QVariant val = KDb::loadPropertyValueFromDom(el.firstChild(), &ok);
             if (!ok) {
                 delete lookupFieldSchema;
-                return 0;
+                return nullptr;
             }
             if (val.type() == QVariant::Bool)
                 lookupFieldSchema->setLimitToList(val.toBool());
