@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003-2016 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2003-2017 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,15 +21,16 @@
 #include "KDbQuerySchema_p.h"
 #include "KDbQuerySchemaParameter.h"
 #include "KDbConnection.h"
+#include "KDbExpression.h"
 #include "KDbLookupFieldSchema.h"
 #include "KDbParser_p.h"
 #include "KDbRelationship.h"
 #include "kdb_debug.h"
 
 KDbOrderByColumn::KDbOrderByColumn()
-        : m_column(0)
+        : m_column(nullptr)
         , m_pos(-1)
-        , m_field(0)
+        , m_field(nullptr)
         , m_ascending(true)
 {
 }
@@ -37,14 +38,14 @@ KDbOrderByColumn::KDbOrderByColumn()
 KDbOrderByColumn::KDbOrderByColumn(KDbQueryColumnInfo* column, bool ascending, int pos)
         : m_column(column)
         , m_pos(pos)
-        , m_field(0)
+        , m_field(nullptr)
         , m_ascending(ascending)
 {
     Q_ASSERT(column);
 }
 
 KDbOrderByColumn::KDbOrderByColumn(KDbField* field, bool ascending)
-        : m_column(0)
+        : m_column(nullptr)
         , m_pos(-1)
         , m_field(field)
         , m_ascending(ascending)
@@ -63,13 +64,13 @@ KDbOrderByColumn* KDbOrderByColumn::copy(KDbQuerySchema* fromQuery, KDbQuerySche
             int columnIndex = fromQuery->columnsOrder().value(m_column);
             if (columnIndex < 0) {
                 kdbDebug() << "KDbOrderByColumn::copy(): Index not found for column" << *m_column;
-                return 0;
+                return nullptr;
             }
             columnInfo = toQuery->expandedOrInternalField(columnIndex);
             if (!columnInfo) {
                 kdbDebug() << "KDbOrderByColumn::copy(): Column info not found at index"
                        << columnIndex << "in toQuery";
-                return 0;
+                return nullptr;
             }
         }
         else {
@@ -78,7 +79,7 @@ KDbOrderByColumn* KDbOrderByColumn::copy(KDbQuerySchema* fromQuery, KDbQuerySche
         return new KDbOrderByColumn(columnInfo, m_ascending, m_pos);
     }
     Q_ASSERT(m_field || m_column);
-    return 0;
+    return nullptr;
 }
 
 KDbOrderByColumn::~KDbOrderByColumn()
@@ -597,7 +598,7 @@ KDbConnection* KDbQuerySchema::connection() const
     if (!d->tables.isEmpty()) {
         return d->tables.first()->connection();
     }
-    return 0;
+    return nullptr;
 }
 
 QDebug operator<<(QDebug dbg, const KDbQuerySchema& query)
@@ -723,7 +724,7 @@ KDbTableSchema* KDbQuerySchema::masterTable() const
     if (d->masterTable)
         return d->masterTable;
     if (d->tables.isEmpty())
-        return 0;
+        return nullptr;
 
     //try to find master table if there's only one table (with possible aliasses)
     QString tableNameLower;
@@ -732,7 +733,7 @@ KDbTableSchema* KDbQuerySchema::masterTable() const
         num++;
         if (!tableNameLower.isEmpty() && table->name().toLower() != tableNameLower) {
             //two or more different tables
-            return 0;
+            return nullptr;
         }
         tableNameLower = tableAlias(num);
     }
@@ -779,7 +780,7 @@ void KDbQuerySchema::removeTable(KDbTableSchema *table)
     if (!table)
         return;
     if (d->masterTable == table)
-        d->masterTable = 0;
+        d->masterTable = nullptr;
     d->tables.removeAt(d->tables.indexOf(table));
 //! @todo remove fields!
 }
@@ -792,7 +793,7 @@ KDbTableSchema* KDbQuerySchema::table(const QString& tableName) const
             return table;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 bool KDbQuerySchema::contains(KDbTableSchema *table) const
@@ -806,18 +807,18 @@ KDbField* KDbQuerySchema::findTableField(const QString &tableOrTableAndFieldName
     if (!KDb::splitToTableAndFieldParts(tableOrTableAndFieldName,
                                         &tableName, &fieldName,
                                         KDb::SetFieldNameIfNoTableName)) {
-        return 0;
+        return nullptr;
     }
     if (tableName.isEmpty()) {
         foreach(KDbTableSchema *table, d->tables) {
             if (table->field(fieldName))
                 return table->field(fieldName);
         }
-        return 0;
+        return nullptr;
     }
     KDbTableSchema *tableSchema = table(tableName);
     if (!tableSchema)
-        return 0;
+        return nullptr;
     return tableSchema->field(fieldName);
 }
 
@@ -964,7 +965,7 @@ KDbField* KDbQuerySchema::field(const QString& name)
 KDbField* KDbQuerySchema::field(const QString& identifier, bool expanded) const
 {
     KDbQueryColumnInfo *ci = columnInfo(identifier, expanded);
-    return ci ? ci->field : 0;
+    return ci ? ci->field : nullptr;
 }
 
 KDbField* KDbQuerySchema::field(int id)
@@ -1125,7 +1126,7 @@ void KDbQuerySchema::computeFieldsExpanded() const
             d->columnsOrderWithoutAsterisks->insert(ci, fieldPosition);
 
             //handle lookup field schema
-            KDbLookupFieldSchema *lookupFieldSchema = f->table() ? f->table()->lookupFieldSchema(*f) : 0;
+            KDbLookupFieldSchema *lookupFieldSchema = f->table() ? f->table()->lookupFieldSchema(*f) : nullptr;
             if (!lookupFieldSchema || lookupFieldSchema->boundColumn() < 0)
                 continue;
             // Lookup field schema found:
@@ -1135,13 +1136,13 @@ void KDbQuerySchema::computeFieldsExpanded() const
             KDbLookupFieldSchema::RecordSource recordSource = lookupFieldSchema->recordSource();
             if (recordSource.type() == KDbLookupFieldSchema::RecordSource::Table) {
                 KDbTableSchema *lookupTable = connection()->tableSchema(recordSource.name());
-                KDbFieldList* visibleColumns = 0;
-                KDbField *boundField = 0;
+                KDbFieldList* visibleColumns = nullptr;
+                KDbField *boundField = nullptr;
                 if (lookupTable
                         && lookupFieldSchema->boundColumn() < lookupTable->fieldCount()
                         && (visibleColumns = lookupTable->subList(lookupFieldSchema->visibleColumns()))
                         && (boundField = lookupTable->field(lookupFieldSchema->boundColumn()))) {
-                    KDbField *visibleColumn = 0;
+                    KDbField *visibleColumn = nullptr;
                     // for single visible column, just add it as-is
                     if (visibleColumns->fieldCount() == 1) {
                         visibleColumn = visibleColumns->fields()->first();
@@ -1181,7 +1182,7 @@ void KDbQuerySchema::computeFieldsExpanded() const
                 const KDbQueryColumnInfo::Vector lookupQueryFieldsExpanded(lookupQuery->fieldsExpanded());
                 if (lookupFieldSchema->boundColumn() >= lookupQueryFieldsExpanded.count())
                     continue;
-                KDbQueryColumnInfo *boundColumnInfo = 0;
+                KDbQueryColumnInfo *boundColumnInfo = nullptr;
                 if (!(boundColumnInfo = lookupQueryFieldsExpanded.value(lookupFieldSchema->boundColumn())))
                     continue;
                 KDbField *boundField = boundColumnInfo->field;
@@ -1198,7 +1199,7 @@ void KDbQuerySchema::computeFieldsExpanded() const
                 }
                 if (!ok)
                     continue;
-                KDbField *visibleColumn = 0;
+                KDbField *visibleColumn = nullptr;
                 // for single visible column, just add it as-is
                 if (visibleColumns.count() == 1) {
                     visibleColumn = lookupQueryFieldsExpanded.value(visibleColumns.first())->field;
@@ -1333,8 +1334,8 @@ void KDbQuerySchema::computeFieldsExpanded() const
     }
     delete d->fieldsExpandedWithInternal; //clear cache
     delete d->fieldsExpandedWithInternalAndRecordId; //clear cache
-    d->fieldsExpandedWithInternal = 0;
-    d->fieldsExpandedWithInternalAndRecordId = 0;
+    d->fieldsExpandedWithInternal = nullptr;
+    d->fieldsExpandedWithInternalAndRecordId = nullptr;
     if (!lookup_list.isEmpty() && !d->internalFields) {//create on demand
         d->internalFields = new KDbQueryColumnInfo::Vector(lookup_list.count());
     }
@@ -1352,13 +1353,13 @@ void KDbQuerySchema::computeFieldsExpanded() const
         KDbQueryColumnInfo* ci = d->fieldsExpanded->at(i);
 //! @todo KDbQuerySchema itself will also support lookup fields...
         KDbLookupFieldSchema *lookupFieldSchema
-        = ci->field->table() ? ci->field->table()->lookupFieldSchema(*ci->field) : 0;
+        = ci->field->table() ? ci->field->table()->lookupFieldSchema(*ci->field) : nullptr;
         if (!lookupFieldSchema || lookupFieldSchema->boundColumn() < 0)
             continue;
         const KDbLookupFieldSchema::RecordSource recordSource = lookupFieldSchema->recordSource();
         if (recordSource.type() == KDbLookupFieldSchema::RecordSource::Table) {
             KDbTableSchema *lookupTable = connection()->tableSchema(recordSource.name());
-            KDbFieldList* visibleColumns = 0;
+            KDbFieldList* visibleColumns = nullptr;
             if (lookupTable
                     && lookupFieldSchema->boundColumn() < lookupTable->fieldCount()
                     && (visibleColumns = lookupTable->subList(lookupFieldSchema->visibleColumns()))) {
@@ -1386,7 +1387,7 @@ void KDbQuerySchema::computeFieldsExpanded() const
             const KDbQueryColumnInfo::Vector lookupQueryFieldsExpanded(lookupQuery->fieldsExpanded());
             if (lookupFieldSchema->boundColumn() >= lookupQueryFieldsExpanded.count())
                 continue;
-            KDbQueryColumnInfo *boundColumnInfo = 0;
+            KDbQueryColumnInfo *boundColumnInfo = nullptr;
             if (!(boundColumnInfo = lookupQueryFieldsExpanded.value(lookupFieldSchema->boundColumn())))
                 continue;
             KDbField *boundField = boundColumnInfo->field;
@@ -1470,7 +1471,7 @@ KDbRelationship* KDbQuerySchema::addRelationship(KDbField *field1, KDbField *fie
     KDbRelationship *r = new KDbRelationship(this, field1, field2);
     if (r->isEmpty()) {
         delete r;
-        return 0;
+        return nullptr;
     }
 
     d->relations.append(r);
@@ -1529,13 +1530,44 @@ KDbEscapedString KDbQuerySchema::autoIncrementSQLFieldsList(KDbConnection *conn)
     return d->autoIncrementSQLFieldsList;
 }
 
-void KDbQuerySchema::setWhereExpression(const KDbExpression& expr)
+static void setResult(const KDbParseInfoInternal &parseInfo,
+                      QString *errorMessage, QString *errorDescription)
 {
-    d->whereExpr = expr.clone();
+    if (errorMessage) {
+        *errorMessage = parseInfo.errorMessage();
+    }
+    if (errorDescription) {
+        *errorDescription = parseInfo.errorDescription();
+    }
 }
 
-void KDbQuerySchema::addToWhereExpression(KDbField *field,
-                                          const QVariant& value, KDbToken relation)
+bool KDbQuerySchema::setWhereExpression(const KDbExpression &expr, QString *errorMessage,
+                                        QString *errorDescription)
+{
+    KDbExpression newWhereExpr = expr.clone();
+    KDbParseInfoInternal parseInfo(this);
+    QString tempErrorMessage;
+    QString tempErrorDescription;
+    QString *errorMessagePointer = errorMessage ? errorMessage : &tempErrorMessage;
+    QString *errorDescriptionPointer
+        = errorDescription ? errorDescription : &tempErrorDescription;
+    if (!newWhereExpr.validate(&parseInfo)) {
+        setResult(parseInfo, errorMessagePointer, errorDescription);
+        kdbWarning() << "message=" << *errorMessagePointer
+                     << "description=" << *errorDescriptionPointer;
+        kdbWarning() << newWhereExpr;
+        d->whereExpr = KDbExpression();
+        return false;
+    }
+    errorMessagePointer->clear();
+    errorDescriptionPointer->clear();
+    Private::setWhereExpressionInternal(this, newWhereExpr);
+    return true;
+}
+
+bool KDbQuerySchema::addToWhereExpression(KDbField *field, const QVariant &value,
+                                          KDbToken relation, QString *errorMessage,
+                                          QString *errorDescription)
 {
     KDbToken token;
     if (value.isNull()) {
@@ -1557,16 +1589,19 @@ void KDbQuerySchema::addToWhereExpression(KDbField *field,
         relation,
         KDbVariableExpression((field->table() ? (field->table()->name() + QLatin1Char('.')) : QString()) + field->name())
     );
-    if (d->whereExpr.isNull()) {
-        d->whereExpr = newExpr;
-    }
-    else {
-        d->whereExpr = KDbBinaryExpression(
+    const KDbExpression origWhereExpr = d->whereExpr;
+    if (!d->whereExpr.isNull()) {
+        newExpr = KDbBinaryExpression(
             d->whereExpr,
             KDbToken::AND,
             newExpr
         );
     }
+    const bool result = setWhereExpression(newExpr, errorMessage, errorDescription);
+    if (!result) { // revert, setWhereExpression() cleared it
+        d->whereExpr = origWhereExpr;
+    }
+    return result;
 }
 
 /*
@@ -1593,7 +1628,7 @@ KDbExpression KDbQuerySchema::whereExpression() const
 void KDbQuerySchema::setOrderByColumnList(const KDbOrderByColumnList& list)
 {
     delete d->orderByColumnList;
-    d->orderByColumnList = new KDbOrderByColumnList(list, 0, 0);
+    d->orderByColumnList = new KDbOrderByColumnList(list, nullptr, nullptr);
 // all field names should be found, exit otherwise ..........?
 }
 
@@ -1609,24 +1644,21 @@ const KDbOrderByColumnList* KDbQuerySchema::orderByColumnList() const
 
 QList<KDbQuerySchemaParameter> KDbQuerySchema::parameters() const
 {
-    if (whereExpression().isNull())
-        return QList<KDbQuerySchemaParameter>();
     QList<KDbQuerySchemaParameter> params;
-    whereExpression().getQueryParameters(&params);
+    const KDbQueryColumnInfo::Vector fieldsExpanded(this->fieldsExpanded());
+    for (int i = 0; i < fieldsExpanded.count(); ++i) {
+        const KDbQueryColumnInfo *ci = fieldsExpanded[i];
+        if (!ci->field->expression().isNull()) {
+            ci->field->expression().getQueryParameters(&params);
+        }
+    }
+    KDbExpression where = whereExpression();
+    if (!where.isNull()) {
+        where.getQueryParameters(&params);
+    }
     return params;
 }
 
-static void setResult(const KDbParseInfoInternal &parseInfo,
-                      QString *errorMessage, QString *errorDescription)
-{
-    if (errorMessage) {
-        *errorMessage = parseInfo.errorMessage();
-    }
-    if (errorDescription) {
-        *errorDescription = parseInfo.errorDescription();
-    }
-}
-
 bool KDbQuerySchema::validate(QString *errorMessage, QString *errorDescription)
 {
     KDbParseInfoInternal parseInfo(this);
